# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/listener/v1/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.interfaces.v1 import history_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2
from bilireq.grpc.protos.bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/listener/v1/listener.proto\x12\x18\x62ilibili.app.listener.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a(bilibili/app/interfaces/v1/history.proto\x1a%bilibili/app/playurl/v1/playurl.proto\"o\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12:\n\x08relation\x18\x04 \x01(\x0b\x32(.bilibili.app.listener.v1.FollowRelation\"\x88\x01\n\x0f\x42KArcDetailsReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x42\n\nplayerArgs\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x42KArcDetailsResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xe4\x01\n\tBKArchive\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03rid\x18\x06 \x01(\x05\x12\r\n\x05rname\x18\x07 \x01(\t\x12\x0f\n\x07publish\x18\x08 \x01(\x03\x12\x15\n\rdisplayed_oid\x18\t \x01(\t\x12\x11\n\tcopyright\x18\n \x01(\x05\x12\x35\n\x06rights\x18\x0b \x01(\x0b\x32%.bilibili.app.listener.v1.BKArcRights\"W\n\tBKArcPart\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0e\n\x06sub_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"!\n\x0b\x42KArcRights\x12\x12\n\nno_reprint\x18\x01 \x01(\x05\"\x98\x01\n\x06\x42KStat\x12\x0c\n\x04like\x18\x01 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x02 \x01(\x05\x12\x11\n\tfavourite\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\r\n\x05share\x18\x05 \x01(\x05\x12\x0c\n\x04view\x18\x06 \x01(\x05\x12\x10\n\x08has_like\x18\x07 \x01(\x08\x12\x10\n\x08has_coin\x18\x08 \x01(\x08\x12\x0f\n\x07has_fav\x18\t \x01(\x08\"\xee\x01\n\nCardModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\x05\x12=\n\rmodule_header\x18\x02 \x01(\x0b\x32$.bilibili.app.listener.v1.PkcmHeaderH\x00\x12?\n\x0emodule_archive\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.PkcmArchiveH\x00\x12\x41\n\x0bmodule_cbtn\x18\x04 \x01(\x0b\x32*.bilibili.app.listener.v1.PkcmCenterButtonH\x00\x42\x08\n\x06module\"\'\n\x08\x43lickReq\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x0b\n\tClickResp\"]\n\nCoinAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\x10\n\x08thumb_up\x18\x03 \x01(\x08\"\x1e\n\x0b\x43oinAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xdf\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\x05\x12\x11\n\tmime_type\x18\x05 \x01(\t\x12\x0e\n\x06\x63odecs\x18\x06 \x01(\t\x12?\n\x0csegment_base\x18\x0c \x01(\x0b\x32).bilibili.app.listener.v1.DashSegmentBase\x12\x0f\n\x07\x63odecid\x18\r \x01(\x05\x12\x0b\n\x03md5\x18\x0e \x01(\t\x12\x0c\n\x04size\x18\x0f \x01(\x03\">\n\x0f\x44\x61shSegmentBase\x12\x16\n\x0einitialization\x18\x01 \x01(\t\x12\x13\n\x0bindex_range\x18\x02 \x01(\t\"\xd3\x05\n\nDetailItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x30\n\x03\x61rc\x18\x02 \x01(\x0b\x32#.bilibili.app.listener.v1.BKArchive\x12\x32\n\x05parts\x18\x03 \x03(\x0b\x32#.bilibili.app.listener.v1.BKArcPart\x12/\n\x05owner\x18\x04 \x01(\x0b\x32 .bilibili.app.listener.v1.Author\x12.\n\x04stat\x18\x05 \x01(\x0b\x32 .bilibili.app.listener.v1.BKStat\x12\x11\n\tlast_part\x18\x06 \x01(\x03\x12\x10\n\x08progress\x18\x07 \x01(\x03\x12\x10\n\x08playable\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12I\n\x0bplayer_info\x18\n \x03(\x0b\x32\x34.bilibili.app.listener.v1.DetailItem.PlayerInfoEntry\x12;\n\x0f\x61ssociated_item\x18\x0b \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x16\n\x0elast_play_time\x18\x0c \x01(\x03\x12\x13\n\x0bhistory_tag\x18\r \x01(\t\x12:\n\x0b\x64\x65vice_type\x18\x0e \x01(\x0b\x32%.bilibili.app.interface.v1.DeviceType\x12<\n\x0fugc_season_info\x18\x0f \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"P\n\x08\x45ventReq\x12\x12\n\nevent_type\x18\x01 \x01(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x0b\n\tEventResp\"~\n\rEventTracking\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x02 \x01(\t\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ntrack_json\x18\x06 \x01(\t\"\xf4\x02\n\tFavFolder\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).bilibili.app.listener.v1.FavFolderAuthor\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07\x66\x61vored\x18\n \x01(\x05\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\r\n\x05mtime\x18\x0c \x01(\x03\x12\x14\n\x0cstat_fav_cnt\x18\r \x01(\x05\x12\x16\n\x0estat_share_cnt\x18\x0e \x01(\x05\x12\x15\n\rstat_like_cnt\x18\x0f \x01(\x05\x12\x15\n\rstat_Play_cnt\x18\x10 \x01(\x05\x12\x16\n\x0estat_reply_cnt\x18\x11 \x01(\x05\x12\x11\n\tfav_state\x18\x12 \x01(\x05\"C\n\x0f\x46\x61vFolderAction\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\",\n\x0f\x46\x61vFolderAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x12\x46\x61vFolderCreateReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06public\x18\x03 \x01(\x05\x12\x13\n\x0b\x66older_type\x18\x04 \x01(\x05\"H\n\x13\x46\x61vFolderCreateResp\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x12\x46\x61vFolderDeleteReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"&\n\x13\x46\x61vFolderDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xaa\x01\n\x12\x46\x61vFolderDetailReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x66\x61v_mid\x18\x03 \x01(\x03\x12\x34\n\tlast_item\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x18\n\x10need_folder_info\x18\x06 \x01(\x08\"\xa8\x01\n\x13\x46\x61vFolderDetailResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x35\n\x04list\x18\x03 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavItemDetail\x12\x38\n\x0b\x66older_info\x18\x04 \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"Z\n\x10\x46\x61vFolderListReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"F\n\x11\x46\x61vFolderListResp\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"1\n\rFavFolderMeta\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"\x96\x01\n\x07\x46\x61vItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03\x66id\x18\x03 \x01(\x03\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05mtime\x18\x05 \x01(\x03\x12\r\n\x05\x63time\x18\x06 \x01(\x03\x12\x33\n\x02\x65t\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\rFavItemAddReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\rFavItemAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xbb\x01\n\x0f\x46\x61vItemBatchReq\x12:\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32).bilibili.app.listener.v1.FavFolderAction\x12\x32\n\x04play\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x03 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"#\n\x10\x46\x61vItemBatchResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9f\x01\n\rFavItemDelReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemDelResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8b\x02\n\rFavItemDetail\x12/\n\x04item\x18\x01 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x36\n\x05owner\x18\x02 \x01(\x0b\x32\'.bilibili.app.listener.v1.FavItemAuthor\x12\x33\n\x04stat\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.FavItemStat\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\r\n\x05parts\x18\t \x01(\x05\"*\n\x0b\x46\x61vItemStat\x12\x0c\n\x04view\x18\x01 \x01(\x05\x12\r\n\x05reply\x18\x02 \x01(\x05\"`\n\x16\x46\x61voredInAnyFoldersReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x85\x01\n\x17\x46\x61voredInAnyFoldersResp\x12\x38\n\x07\x66olders\x18\x01 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavFolderMeta\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x1c\n\rFavTabShowReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"#\n\x0e\x46\x61vTabShowResp\x12\x11\n\tshow_menu\x18\x01 \x01(\x08\" \n\x0e\x46ollowRelation\x12\x0e\n\x06status\x18\x01 \x01(\x05\"t\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x04 \x01(\t\x12\x13\n\x0bsuperscript\x18\x05 \x01(\t\";\n\x17MainFavMusicMenuListReq\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\"\x86\x01\n\x18MainFavMusicMenuListResp\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x36\n\tmenu_list\x18\x02 \x03(\x0b\x32#.bilibili.app.listener.v1.MusicMenu\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\"\x1b\n\x19MainFavMusicSubTabListReq\"\xe7\x02\n\x1aMainFavMusicSubTabListResp\x12\x33\n\x04tabs\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.MusicSubTab\x12K\n\x0f\x64\x65\x66\x61ult_tab_res\x18\x02 \x01(\x0b\x32\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp\x12^\n\x0e\x66irst_page_res\x18\x03 \x03(\x0b\x32\x46.bilibili.app.listener.v1.MainFavMusicSubTabListResp.FirstPageResEntry\x1ag\n\x11\x46irstPageResEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp:\x02\x38\x01\"\xe8\x01\n\rMedialistItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\r\n\x05parts\x18\x05 \x01(\x05\x12\x0e\n\x06up_mid\x18\x06 \x01(\x03\x12\x0f\n\x07up_name\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12\x11\n\tstat_view\x18\n \x01(\x03\x12\x12\n\nstat_reply\x18\x0b \x01(\x03\"A\n\x0cMedialistReq\x12\x11\n\tlist_type\x18\x01 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\"\xb4\x01\n\rMedialistResp\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x36\n\x05items\x18\x04 \x03(\x0b\x32\'.bilibili.app.listener.v1.MedialistItem\x12:\n\x07up_info\x18\x05 \x01(\x0b\x32).bilibili.app.listener.v1.MedialistUpInfo\"J\n\x0fMedialistUpInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0e\n\x06\x61vatar\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x1b\n\rMenuDeleteReq\x12\n\n\x02id\x18\x01 \x01(\x03\"!\n\x0eMenuDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"I\n\x0bMenuEditReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x11\n\tis_public\x18\x04 \x01(\x05\"\x1f\n\x0cMenuEditResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"5\n\x10MenuSubscribeReq\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x11\n\ttarget_id\x18\x02 \x01(\x03\"$\n\x11MenuSubscribeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8f\x02\n\tMusicMenu\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tmenu_type\x18\x02 \x01(\x05\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x38\n\x05owner\x18\x06 \x01(\x0b\x32).bilibili.app.listener.v1.MusicMenuAuthor\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x03\x12\x35\n\x04stat\x18\t \x01(\x0b\x32\'.bilibili.app.listener.v1.MusicMenuStat\x12\r\n\x05total\x18\n \x01(\x03\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\x0b\n\x03uri\x18\x0c \x01(\t\"<\n\x0fMusicMenuAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\",\n\rMusicMenuStat\x12\x0c\n\x04play\x18\x01 \x01(\x03\x12\r\n\x05reply\x18\x02 \x01(\x03\"<\n\x0bMusicSubTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08tab_type\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x03\"i\n\nPageOption\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x35\n\tlast_item\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x81\x02\n\x0bPickArchive\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12:\n\x05owner\x18\x03 \x01(\x0b\x32+.bilibili.app.listener.v1.PickArchiveAuthor\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\r\n\x05parts\x18\x06 \x01(\x05\x12\x11\n\tstat_view\x18\x07 \x01(\x05\x12\x12\n\nstat_reply\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\t\".\n\x11PickArchiveAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x08PickCard\x12\x0f\n\x07pick_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\x03\x12\x11\n\tcard_name\x18\x03 \x01(\t\x12\x35\n\x07modules\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"5\n\x11PickCardDetailReq\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\"m\n\x12PickCardDetailResp\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\x12\x35\n\x07modules\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"\x1d\n\x0bPickFeedReq\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"Q\n\x0cPickFeedResp\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x31\n\x05\x63\x61rds\x18\x02 \x03(\x0b\x32\".bilibili.app.listener.v1.PickCard\"V\n\x0bPkcmArchive\x12\x32\n\x03\x61rc\x18\x01 \x01(\x0b\x32%.bilibili.app.listener.v1.PickArchive\x12\x13\n\x0bpick_reason\x18\x02 \x01(\t\"T\n\x10PkcmCenterButton\x12\x11\n\ticon_head\x18\x01 \x01(\t\x12\x11\n\ticon_tail\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"^\n\nPkcmHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08\x62tn_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62tn_text\x18\x04 \x01(\t\x12\x0f\n\x07\x62tn_uri\x18\x05 \x01(\t\"[\n\x13PlayActionReportReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x12\n\nfrom_spmid\x18\x02 \x01(\t\"h\n\x08PlayDASH\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x17\n\x0fmin_buffer_time\x18\x02 \x01(\x02\x12\x31\n\x05\x61udio\x18\x03 \x03(\x0b\x32\".bilibili.app.listener.v1.DashItem\"}\n\x11PlayHistoryAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x12\n\nplay_style\x18\x04 \x01(\x05\"X\n\x11PlayHistoryDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"b\n\x0ePlayHistoryReq\x12\x36\n\x08page_opt\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x18\n\x10local_today_zero\x18\x02 \x01(\x03\"g\n\x0fPlayHistoryResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xee\x02\n\x08PlayInfo\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0f\n\x07qn_type\x18\x03 \x01(\x05\x12\x35\n\x08play_url\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.PlayURLH\x00\x12\x37\n\tplay_dash\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayDASHH\x00\x12\r\n\x05\x66nver\x18\x06 \x01(\x05\x12\r\n\x05\x66nval\x18\x07 \x01(\x05\x12\x0f\n\x07\x66ormats\x18\x08 \x03(\x05\x12\x15\n\rvideo_codecid\x18\t \x01(\x05\x12\x0e\n\x06length\x18\n \x01(\x03\x12\x0c\n\x04\x63ode\x18\x0b \x01(\x05\x12\x0f\n\x07message\x18\x0c \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\r \x01(\x03\x12\x33\n\x06volume\x18\x0e \x01(\x0b\x32#.bilibili.app.playurl.v1.VolumeInfoB\x06\n\x04info\"o\n\x08PlayItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0e\n\x06sub_id\x18\x04 \x03(\x03\x12\x33\n\x02\x65t\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\x0ePlaylistAddReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x0e\n\x04head\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04tail\x18\x04 \x01(\x08H\x00\x42\x05\n\x03pos\"U\n\x0ePlaylistDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"\xa2\x02\n\x0bPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x32\n\x06\x61nchor\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x36\n\x08page_opt\x18\x04 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08\x65xtra_id\x18\x06 \x01(\x03\x12\x36\n\x08sort_opt\x18\x07 \x01(\x0b\x32$.bilibili.app.listener.v1.SortOption\"\xc7\x01\n\x0cPlaylistResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x13\n\x0breach_start\x18\x02 \x01(\x08\x12\x11\n\treach_end\x18\x03 \x01(\x08\x12\x32\n\x04list\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x35\n\tlast_play\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x15\n\rlast_progress\x18\x06 \x01(\x03\">\n\x07PlayURL\x12\x33\n\x04\x64url\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.ResponseUrl\"\x83\x01\n\nPlayURLReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x43\n\x0bplayer_args\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x84\x02\n\x0bPlayURLResp\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08playable\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12I\n\nplayerInfo\x18\x04 \x03(\x0b\x32\x35.bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"\x9e\x01\n\x0fRcmdPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x14\n\x0cneed_history\x18\x03 \x01(\x08\x12\x16\n\x0eneed_top_cards\x18\x04 \x01(\x08\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x91\x01\n\x10RcmdPlaylistResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x13\n\x0bhistory_len\x18\x02 \x01(\x03\x12\x34\n\ttop_cards\x18\x03 \x03(\x0b\x32!.bilibili.app.listener.v1.TopCard\"\x86\x01\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\r\n\x05\x61head\x18\x04 \x01(\t\x12\r\n\x05vhead\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x12\n\nbackup_url\x18\x07 \x03(\t\x12\x0b\n\x03md5\x18\x08 \x01(\t\"/\n\nSortOption\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x12\n\nsort_field\x18\x02 \x01(\x05\"N\n\nThumbUpReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x1e\n\x0bThumbUpResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xe4\x02\n\x07TopCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x12\n\nplay_style\x18\x02 \x01(\x05\x12\x11\n\tcard_type\x18\x03 \x01(\x05\x12?\n\x0elisten_history\x18\x04 \x01(\x0b\x32%.bilibili.app.listener.v1.TpcdHistoryH\x00\x12=\n\nfav_folder\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.TpcdFavFolderH\x00\x12;\n\tup_recall\x18\x06 \x01(\x0b\x32&.bilibili.app.listener.v1.TpcdUpRecallH\x00\x12=\n\npick_today\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.TpcdPickTodayH\x00\x12\x0b\n\x03pos\x18\x08 \x01(\x03\x12\x12\n\ntitle_icon\x18\t \x01(\tB\x06\n\x04\x63\x61rd\"\x80\x01\n\rTpcdFavFolder\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\x12\x0b\n\x03\x66id\x18\x04 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x05 \x01(\x05\"\\\n\x0bTpcdHistory\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\"\x85\x01\n\rTpcdPickToday\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\x12\x0f\n\x07pick_id\x18\x04 \x01(\x03\x12\x14\n\x0cpick_card_id\x18\x05 \x01(\x03\"\xa2\x01\n\x0cTpcdUpRecall\x12\x0e\n\x06up_mid\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12\x16\n\x0emedialist_type\x18\x04 \x01(\x03\x12\x18\n\x10medialist_biz_id\x18\x05 \x01(\x03\x12\x32\n\x04item\x18\x06 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"A\n\rTripleLikeReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"T\n\x0eTripleLikeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08thumb_ok\x18\x02 \x01(\x08\x12\x0f\n\x07\x63oin_ok\x18\x03 \x01(\x08\x12\x0e\n\x06\x66\x61v_ok\x18\x04 \x01(\x08*\\\n\x0e\x43\x61rdModuleType\x12\x12\n\x0eModule_invalid\x10\x00\x12\x11\n\rModule_header\x10\x01\x12\x12\n\x0eModule_archive\x10\x02\x12\x0f\n\x0bModule_cbtn\x10\x03*P\n\tListOrder\x12\x0c\n\x08NO_ORDER\x10\x00\x12\x10\n\x0cORDER_NORMAL\x10\x01\x12\x11\n\rORDER_REVERSE\x10\x02\x12\x10\n\x0cORDER_RANDOM\x10\x03*O\n\rListSortField\x12\x0b\n\x07NO_SORT\x10\x00\x12\x0e\n\nSORT_CTIME\x10\x01\x12\x10\n\x0cSORT_VIEWCNT\x10\x02\x12\x0f\n\x0bSORT_FAVCNT\x10\x03*\xa6\x01\n\x0ePlaylistSource\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tMEM_SPACE\x10\x01\x12\x14\n\x10\x41UDIO_COLLECTION\x10\x02\x12\x0e\n\nAUDIO_CARD\x10\x03\x12\x12\n\x0eUSER_FAVOURITE\x10\x04\x12\x0e\n\nUP_ARCHIVE\x10\x05\x12\x0f\n\x0b\x41UDIO_CACHE\x10\x06\x12\r\n\tPICK_CARD\x10\x07\x12\x0e\n\nMEDIA_LIST\x10\x08*f\n\x0bTopCardType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x12\n\x0eLISTEN_HISTORY\x10\x01\x12\x13\n\x0f\x46\x41VORITE_FOLDER\x10\x02\x12\r\n\tUP_RECALL\x10\x03\x12\x0e\n\nPICK_TODAY\x10\x04\x32\xba\x13\n\x08Listener\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12V\n\x07PlayUrl\x12$.bilibili.app.listener.v1.PlayURLReq\x1a%.bilibili.app.listener.v1.PlayURLResp\x12\x65\n\x0c\x42karcDetails\x12).bilibili.app.listener.v1.BKArcDetailsReq\x1a*.bilibili.app.listener.v1.BKArcDetailsResp\x12Y\n\x08Playlist\x12%.bilibili.app.listener.v1.PlaylistReq\x1a&.bilibili.app.listener.v1.PlaylistResp\x12O\n\x0bPlaylistAdd\x12(.bilibili.app.listener.v1.PlaylistAddReq\x1a\x16.google.protobuf.Empty\x12O\n\x0bPlaylistDel\x12(.bilibili.app.listener.v1.PlaylistDelReq\x1a\x16.google.protobuf.Empty\x12\x65\n\x0cRcmdPlaylist\x12).bilibili.app.listener.v1.RcmdPlaylistReq\x1a*.bilibili.app.listener.v1.RcmdPlaylistResp\x12\x62\n\x0bPlayHistory\x12(.bilibili.app.listener.v1.PlayHistoryReq\x1a).bilibili.app.listener.v1.PlayHistoryResp\x12U\n\x0ePlayHistoryAdd\x12+.bilibili.app.listener.v1.PlayHistoryAddReq\x1a\x16.google.protobuf.Empty\x12U\n\x0ePlayHistoryDel\x12+.bilibili.app.listener.v1.PlayHistoryDelReq\x1a\x16.google.protobuf.Empty\x12Y\n\x10PlayActionReport\x12-.bilibili.app.listener.v1.PlayActionReportReq\x1a\x16.google.protobuf.Empty\x12_\n\nTripleLike\x12\'.bilibili.app.listener.v1.TripleLikeReq\x1a(.bilibili.app.listener.v1.TripleLikeResp\x12V\n\x07ThumbUp\x12$.bilibili.app.listener.v1.ThumbUpReq\x1a%.bilibili.app.listener.v1.ThumbUpResp\x12V\n\x07\x43oinAdd\x12$.bilibili.app.listener.v1.CoinAddReq\x1a%.bilibili.app.listener.v1.CoinAddResp\x12_\n\nFavItemAdd\x12\'.bilibili.app.listener.v1.FavItemAddReq\x1a(.bilibili.app.listener.v1.FavItemAddResp\x12_\n\nFavItemDel\x12\'.bilibili.app.listener.v1.FavItemDelReq\x1a(.bilibili.app.listener.v1.FavItemDelResp\x12\x65\n\x0c\x46\x61vItemBatch\x12).bilibili.app.listener.v1.FavItemBatchReq\x1a*.bilibili.app.listener.v1.FavItemBatchResp\x12z\n\x13\x46\x61voredInAnyFolders\x12\x30.bilibili.app.listener.v1.FavoredInAnyFoldersReq\x1a\x31.bilibili.app.listener.v1.FavoredInAnyFoldersResp\x12h\n\rFavFolderList\x12*.bilibili.app.listener.v1.FavFolderListReq\x1a+.bilibili.app.listener.v1.FavFolderListResp\x12n\n\x0f\x46\x61vFolderDetail\x12,.bilibili.app.listener.v1.FavFolderDetailReq\x1a-.bilibili.app.listener.v1.FavFolderDetailResp\x12n\n\x0f\x46\x61vFolderCreate\x12,.bilibili.app.listener.v1.FavFolderCreateReq\x1a-.bilibili.app.listener.v1.FavFolderCreateResp\x12n\n\x0f\x46\x61vFolderDelete\x12,.bilibili.app.listener.v1.FavFolderDeleteReq\x1a-.bilibili.app.listener.v1.FavFolderDeleteResp\x12Y\n\x08PickFeed\x12%.bilibili.app.listener.v1.PickFeedReq\x1a&.bilibili.app.listener.v1.PickFeedResp\x12k\n\x0ePickCardDetail\x12+.bilibili.app.listener.v1.PickCardDetailReq\x1a,.bilibili.app.listener.v1.PickCardDetailResp\x12\\\n\tMedialist\x12&.bilibili.app.listener.v1.MedialistReq\x1a\'.bilibili.app.listener.v1.MedialistResp\x12P\n\x05\x45vent\x12\".bilibili.app.listener.v1.EventReq\x1a#.bilibili.app.listener.v1.EventResp2\xe5\x05\n\x05Music\x12_\n\nFavTabShow\x12\'.bilibili.app.listener.v1.FavTabShowReq\x1a(.bilibili.app.listener.v1.FavTabShowResp\x12\x83\x01\n\x16MainFavMusicSubTabList\x12\x33.bilibili.app.listener.v1.MainFavMusicSubTabListReq\x1a\x34.bilibili.app.listener.v1.MainFavMusicSubTabListResp\x12}\n\x14MainFavMusicMenuList\x12\x31.bilibili.app.listener.v1.MainFavMusicMenuListReq\x1a\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp\x12Y\n\x08MenuEdit\x12%.bilibili.app.listener.v1.MenuEditReq\x1a&.bilibili.app.listener.v1.MenuEditResp\x12_\n\nMenuDelete\x12\'.bilibili.app.listener.v1.MenuDeleteReq\x1a(.bilibili.app.listener.v1.MenuDeleteResp\x12h\n\rMenuSubscribe\x12*.bilibili.app.listener.v1.MenuSubscribeReq\x1a+.bilibili.app.listener.v1.MenuSubscribeResp\x12P\n\x05\x43lick\x12\".bilibili.app.listener.v1.ClickReq\x1a#.bilibili.app.listener.v1.ClickRespb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.listener.v1.listener_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETAILITEM_PLAYERINFOENTRY._options = None
  _DETAILITEM_PLAYERINFOENTRY._serialized_options = b'8\001'
  _MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY._options = None
  _MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY._serialized_options = b'8\001'
  _PLAYURLRESP_PLAYERINFOENTRY._options = None
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_options = b'8\001'
  _globals['_CARDMODULETYPE']._serialized_start=12512
  _globals['_CARDMODULETYPE']._serialized_end=12604
  _globals['_LISTORDER']._serialized_start=12606
  _globals['_LISTORDER']._serialized_end=12686
  _globals['_LISTSORTFIELD']._serialized_start=12688
  _globals['_LISTSORTFIELD']._serialized_end=12767
  _globals['_PLAYLISTSOURCE']._serialized_start=12770
  _globals['_PLAYLISTSOURCE']._serialized_end=12936
  _globals['_TOPCARDTYPE']._serialized_start=12938
  _globals['_TOPCARDTYPE']._serialized_end=13040
  _globals['_AUTHOR']._serialized_start=229
  _globals['_AUTHOR']._serialized_end=340
  _globals['_BKARCDETAILSREQ']._serialized_start=343
  _globals['_BKARCDETAILSREQ']._serialized_end=479
  _globals['_BKARCDETAILSRESP']._serialized_start=481
  _globals['_BKARCDETAILSRESP']._serialized_end=551
  _globals['_BKARCHIVE']._serialized_start=554
  _globals['_BKARCHIVE']._serialized_end=782
  _globals['_BKARCPART']._serialized_start=784
  _globals['_BKARCPART']._serialized_end=871
  _globals['_BKARCRIGHTS']._serialized_start=873
  _globals['_BKARCRIGHTS']._serialized_end=906
  _globals['_BKSTAT']._serialized_start=909
  _globals['_BKSTAT']._serialized_end=1061
  _globals['_CARDMODULE']._serialized_start=1064
  _globals['_CARDMODULE']._serialized_end=1302
  _globals['_CLICKREQ']._serialized_start=1304
  _globals['_CLICKREQ']._serialized_end=1343
  _globals['_CLICKRESP']._serialized_start=1345
  _globals['_CLICKRESP']._serialized_end=1356
  _globals['_COINADDREQ']._serialized_start=1358
  _globals['_COINADDREQ']._serialized_end=1451
  _globals['_COINADDRESP']._serialized_start=1453
  _globals['_COINADDRESP']._serialized_end=1483
  _globals['_DASHITEM']._serialized_start=1486
  _globals['_DASHITEM']._serialized_end=1709
  _globals['_DASHSEGMENTBASE']._serialized_start=1711
  _globals['_DASHSEGMENTBASE']._serialized_end=1773
  _globals['_DETAILITEM']._serialized_start=1776
  _globals['_DETAILITEM']._serialized_end=2499
  _globals['_DETAILITEM_PLAYERINFOENTRY']._serialized_start=2414
  _globals['_DETAILITEM_PLAYERINFOENTRY']._serialized_end=2499
  _globals['_EVENTREQ']._serialized_start=2501
  _globals['_EVENTREQ']._serialized_end=2581
  _globals['_EVENTRESP']._serialized_start=2583
  _globals['_EVENTRESP']._serialized_end=2594
  _globals['_EVENTTRACKING']._serialized_start=2596
  _globals['_EVENTTRACKING']._serialized_end=2722
  _globals['_FAVFOLDER']._serialized_start=2725
  _globals['_FAVFOLDER']._serialized_end=3097
  _globals['_FAVFOLDERACTION']._serialized_start=3099
  _globals['_FAVFOLDERACTION']._serialized_end=3166
  _globals['_FAVFOLDERAUTHOR']._serialized_start=3168
  _globals['_FAVFOLDERAUTHOR']._serialized_end=3212
  _globals['_FAVFOLDERCREATEREQ']._serialized_start=3214
  _globals['_FAVFOLDERCREATEREQ']._serialized_end=3299
  _globals['_FAVFOLDERCREATERESP']._serialized_start=3301
  _globals['_FAVFOLDERCREATERESP']._serialized_end=3373
  _globals['_FAVFOLDERDELETEREQ']._serialized_start=3375
  _globals['_FAVFOLDERDELETEREQ']._serialized_end=3429
  _globals['_FAVFOLDERDELETERESP']._serialized_start=3431
  _globals['_FAVFOLDERDELETERESP']._serialized_end=3469
  _globals['_FAVFOLDERDETAILREQ']._serialized_start=3472
  _globals['_FAVFOLDERDETAILREQ']._serialized_end=3642
  _globals['_FAVFOLDERDETAILRESP']._serialized_start=3645
  _globals['_FAVFOLDERDETAILRESP']._serialized_end=3813
  _globals['_FAVFOLDERLISTREQ']._serialized_start=3815
  _globals['_FAVFOLDERLISTREQ']._serialized_end=3905
  _globals['_FAVFOLDERLISTRESP']._serialized_start=3907
  _globals['_FAVFOLDERLISTRESP']._serialized_end=3977
  _globals['_FAVFOLDERMETA']._serialized_start=3979
  _globals['_FAVFOLDERMETA']._serialized_end=4028
  _globals['_FAVITEM']._serialized_start=4031
  _globals['_FAVITEM']._serialized_end=4181
  _globals['_FAVITEMADDREQ']._serialized_start=4184
  _globals['_FAVITEMADDREQ']._serialized_end=4343
  _globals['_FAVITEMADDRESP']._serialized_start=4345
  _globals['_FAVITEMADDRESP']._serialized_end=4378
  _globals['_FAVITEMAUTHOR']._serialized_start=4380
  _globals['_FAVITEMAUTHOR']._serialized_end=4422
  _globals['_FAVITEMBATCHREQ']._serialized_start=4425
  _globals['_FAVITEMBATCHREQ']._serialized_end=4612
  _globals['_FAVITEMBATCHRESP']._serialized_start=4614
  _globals['_FAVITEMBATCHRESP']._serialized_end=4649
  _globals['_FAVITEMDELREQ']._serialized_start=4652
  _globals['_FAVITEMDELREQ']._serialized_end=4811
  _globals['_FAVITEMDELRESP']._serialized_start=4813
  _globals['_FAVITEMDELRESP']._serialized_end=4846
  _globals['_FAVITEMDETAIL']._serialized_start=4849
  _globals['_FAVITEMDETAIL']._serialized_end=5116
  _globals['_FAVITEMSTAT']._serialized_start=5118
  _globals['_FAVITEMSTAT']._serialized_end=5160
  _globals['_FAVOREDINANYFOLDERSREQ']._serialized_start=5162
  _globals['_FAVOREDINANYFOLDERSREQ']._serialized_end=5258
  _globals['_FAVOREDINANYFOLDERSRESP']._serialized_start=5261
  _globals['_FAVOREDINANYFOLDERSRESP']._serialized_end=5394
  _globals['_FAVTABSHOWREQ']._serialized_start=5396
  _globals['_FAVTABSHOWREQ']._serialized_end=5424
  _globals['_FAVTABSHOWRESP']._serialized_start=5426
  _globals['_FAVTABSHOWRESP']._serialized_end=5461
  _globals['_FOLLOWRELATION']._serialized_start=5463
  _globals['_FOLLOWRELATION']._serialized_end=5495
  _globals['_FORMATDESCRIPTION']._serialized_start=5497
  _globals['_FORMATDESCRIPTION']._serialized_end=5613
  _globals['_MAINFAVMUSICMENULISTREQ']._serialized_start=5615
  _globals['_MAINFAVMUSICMENULISTREQ']._serialized_end=5674
  _globals['_MAINFAVMUSICMENULISTRESP']._serialized_start=5677
  _globals['_MAINFAVMUSICMENULISTRESP']._serialized_end=5811
  _globals['_MAINFAVMUSICSUBTABLISTREQ']._serialized_start=5813
  _globals['_MAINFAVMUSICSUBTABLISTREQ']._serialized_end=5840
  _globals['_MAINFAVMUSICSUBTABLISTRESP']._serialized_start=5843
  _globals['_MAINFAVMUSICSUBTABLISTRESP']._serialized_end=6202
  _globals['_MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY']._serialized_start=6099
  _globals['_MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY']._serialized_end=6202
  _globals['_MEDIALISTITEM']._serialized_start=6205
  _globals['_MEDIALISTITEM']._serialized_end=6437
  _globals['_MEDIALISTREQ']._serialized_start=6439
  _globals['_MEDIALISTREQ']._serialized_end=6504
  _globals['_MEDIALISTRESP']._serialized_start=6507
  _globals['_MEDIALISTRESP']._serialized_end=6687
  _globals['_MEDIALISTUPINFO']._serialized_start=6689
  _globals['_MEDIALISTUPINFO']._serialized_end=6763
  _globals['_MENUDELETEREQ']._serialized_start=6765
  _globals['_MENUDELETEREQ']._serialized_end=6792
  _globals['_MENUDELETERESP']._serialized_start=6794
  _globals['_MENUDELETERESP']._serialized_end=6827
  _globals['_MENUEDITREQ']._serialized_start=6829
  _globals['_MENUEDITREQ']._serialized_end=6902
  _globals['_MENUEDITRESP']._serialized_start=6904
  _globals['_MENUEDITRESP']._serialized_end=6935
  _globals['_MENUSUBSCRIBEREQ']._serialized_start=6937
  _globals['_MENUSUBSCRIBEREQ']._serialized_end=6990
  _globals['_MENUSUBSCRIBERESP']._serialized_start=6992
  _globals['_MENUSUBSCRIBERESP']._serialized_end=7028
  _globals['_MUSICMENU']._serialized_start=7031
  _globals['_MUSICMENU']._serialized_end=7302
  _globals['_MUSICMENUAUTHOR']._serialized_start=7304
  _globals['_MUSICMENUAUTHOR']._serialized_end=7364
  _globals['_MUSICMENUSTAT']._serialized_start=7366
  _globals['_MUSICMENUSTAT']._serialized_end=7410
  _globals['_MUSICSUBTAB']._serialized_start=7412
  _globals['_MUSICSUBTAB']._serialized_end=7472
  _globals['_PAGEOPTION']._serialized_start=7474
  _globals['_PAGEOPTION']._serialized_end=7579
  _globals['_PICKARCHIVE']._serialized_start=7582
  _globals['_PICKARCHIVE']._serialized_end=7839
  _globals['_PICKARCHIVEAUTHOR']._serialized_start=7841
  _globals['_PICKARCHIVEAUTHOR']._serialized_end=7887
  _globals['_PICKCARD']._serialized_start=7889
  _globals['_PICKCARD']._serialized_end=8007
  _globals['_PICKCARDDETAILREQ']._serialized_start=8009
  _globals['_PICKCARDDETAILREQ']._serialized_end=8062
  _globals['_PICKCARDDETAILRESP']._serialized_start=8064
  _globals['_PICKCARDDETAILRESP']._serialized_end=8173
  _globals['_PICKFEEDREQ']._serialized_start=8175
  _globals['_PICKFEEDREQ']._serialized_end=8204
  _globals['_PICKFEEDRESP']._serialized_start=8206
  _globals['_PICKFEEDRESP']._serialized_end=8287
  _globals['_PKCMARCHIVE']._serialized_start=8289
  _globals['_PKCMARCHIVE']._serialized_end=8375
  _globals['_PKCMCENTERBUTTON']._serialized_start=8377
  _globals['_PKCMCENTERBUTTON']._serialized_end=8461
  _globals['_PKCMHEADER']._serialized_start=8463
  _globals['_PKCMHEADER']._serialized_end=8557
  _globals['_PLAYACTIONREPORTREQ']._serialized_start=8559
  _globals['_PLAYACTIONREPORTREQ']._serialized_end=8650
  _globals['_PLAYDASH']._serialized_start=8652
  _globals['_PLAYDASH']._serialized_end=8756
  _globals['_PLAYHISTORYADDREQ']._serialized_start=8758
  _globals['_PLAYHISTORYADDREQ']._serialized_end=8883
  _globals['_PLAYHISTORYDELREQ']._serialized_start=8885
  _globals['_PLAYHISTORYDELREQ']._serialized_end=8973
  _globals['_PLAYHISTORYREQ']._serialized_start=8975
  _globals['_PLAYHISTORYREQ']._serialized_end=9073
  _globals['_PLAYHISTORYRESP']._serialized_start=9075
  _globals['_PLAYHISTORYRESP']._serialized_end=9178
  _globals['_PLAYINFO']._serialized_start=9181
  _globals['_PLAYINFO']._serialized_end=9547
  _globals['_PLAYITEM']._serialized_start=9549
  _globals['_PLAYITEM']._serialized_end=9660
  _globals['_PLAYLISTADDREQ']._serialized_start=9663
  _globals['_PLAYLISTADDREQ']._serialized_end=9822
  _globals['_PLAYLISTDELREQ']._serialized_start=9824
  _globals['_PLAYLISTDELREQ']._serialized_end=9909
  _globals['_PLAYLISTREQ']._serialized_start=9912
  _globals['_PLAYLISTREQ']._serialized_end=10202
  _globals['_PLAYLISTRESP']._serialized_start=10205
  _globals['_PLAYLISTRESP']._serialized_end=10404
  _globals['_PLAYURL']._serialized_start=10406
  _globals['_PLAYURL']._serialized_end=10468
  _globals['_PLAYURLREQ']._serialized_start=10471
  _globals['_PLAYURLREQ']._serialized_end=10602
  _globals['_PLAYURLRESP']._serialized_start=10605
  _globals['_PLAYURLRESP']._serialized_end=10865
  _globals['_PLAYURLRESP_PLAYERINFOENTRY']._serialized_start=2414
  _globals['_PLAYURLRESP_PLAYERINFOENTRY']._serialized_end=2499
  _globals['_RCMDPLAYLISTREQ']._serialized_start=10868
  _globals['_RCMDPLAYLISTREQ']._serialized_end=11026
  _globals['_RCMDPLAYLISTRESP']._serialized_start=11029
  _globals['_RCMDPLAYLISTRESP']._serialized_end=11174
  _globals['_RESPONSEURL']._serialized_start=11177
  _globals['_RESPONSEURL']._serialized_end=11311
  _globals['_SORTOPTION']._serialized_start=11313
  _globals['_SORTOPTION']._serialized_end=11360
  _globals['_THUMBUPREQ']._serialized_start=11362
  _globals['_THUMBUPREQ']._serialized_end=11440
  _globals['_THUMBUPRESP']._serialized_start=11442
  _globals['_THUMBUPRESP']._serialized_end=11472
  _globals['_TOPCARD']._serialized_start=11475
  _globals['_TOPCARD']._serialized_end=11831
  _globals['_TPCDFAVFOLDER']._serialized_start=11834
  _globals['_TPCDFAVFOLDER']._serialized_end=11962
  _globals['_TPCDHISTORY']._serialized_start=11964
  _globals['_TPCDHISTORY']._serialized_end=12056
  _globals['_TPCDPICKTODAY']._serialized_start=12059
  _globals['_TPCDPICKTODAY']._serialized_end=12192
  _globals['_TPCDUPRECALL']._serialized_start=12195
  _globals['_TPCDUPRECALL']._serialized_end=12357
  _globals['_TRIPLELIKEREQ']._serialized_start=12359
  _globals['_TRIPLELIKEREQ']._serialized_end=12424
  _globals['_TRIPLELIKERESP']._serialized_start=12426
  _globals['_TRIPLELIKERESP']._serialized_end=12510
  _globals['_LISTENER']._serialized_start=13043
  _globals['_LISTENER']._serialized_end=15533
  _globals['_MUSIC']._serialized_start=15536
  _globals['_MUSIC']._serialized_end=16277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pangu/gallery/v1/gallery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/pangu/gallery/v1/gallery.proto\x12\x19\x62ilibili.pangu.gallery.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x12\n\x10\x41greePolicyReply\"]\n\x0e\x41greePolicyReq\x12:\n\x0bpolicy_type\x18\x01 \x01(\x0e\x32%.bilibili.pangu.gallery.v1.PolicyType\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x8a\x01\n\x0e\x42\x61sicInfoReply\x12\x1c\n\x14\x63ustomer_service_url\x18\x01 \x01(\t\x12\x15\n\ragreement_url\x18\x02 \x01(\t\x12\x13\n\x0bprivacy_url\x18\x03 \x01(\t\x12.\n\x05links\x18\x04 \x03(\x0b\x32\x1f.bilibili.pangu.gallery.v1.Link\"\x1b\n\x0c\x42\x61sicInfoReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"^\n\x07\x44isplay\x12\x16\n\x0e\x62g_theme_light\x18\x01 \x01(\t\x12\x16\n\x0e\x62g_theme_night\x18\x02 \x01(\t\x12\x12\n\nnft_poster\x18\x03 \x01(\t\x12\x0f\n\x07nft_raw\x18\x04 \x01(\t\"N\n\x12GetLastPolicyReply\x12\x12\n\nshort_desc\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65tail_jump\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"N\n\x10GetLastPolicyReq\x12:\n\x0bpolicy_type\x18\x01 \x01(\x0e\x32%.bilibili.pangu.gallery.v1.PolicyType\"d\n\x10GetUserInfoReply\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x12\n\navatar_url\x18\x04 \x01(\t\x12\x10\n\x08help_url\x18\x05 \x01(\t\"\x1d\n\x0eGetUserInfoReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\">\n\x04Link\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08link_url\x18\x02 \x01(\t\x12\x16\n\x0etrack_event_id\x18\x03 \x01(\t\"a\n\x11ListNFTByMidReply\x12,\n\x04nfts\x18\x01 \x03(\x0b\x32\x1e.bilibili.pangu.gallery.v1.NFT\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x08\"h\n\x0fListNFTByMidReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x62iz_type\x18\x03 \x01(\t\x12\x11\n\tanchor_id\x18\x04 \x01(\x03\x12\x11\n\tpage_size\x18\x05 \x01(\x03\"g\n\x13ListOrderByMidReply\x12\x30\n\x06orders\x18\x01 \x03(\x0b\x32 .bilibili.pangu.gallery.v1.Order\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x08\"F\n\x11ListOrderByMidReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x11\n\tpage_size\x18\x03 \x01(\x03\"\xe3\x01\n\x03NFT\x12\x0e\n\x06nft_id\x18\x01 \x01(\t\x12\x11\n\titem_name\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x0e\n\x06issuer\x18\x04 \x01(\t\x12\x33\n\x07\x64isplay\x18\x05 \x01(\x0b\x32\".bilibili.pangu.gallery.v1.Display\x12\x12\n\ndetail_url\x18\x06 \x01(\t\x12\x38\n\nnft_status\x18\x07 \x01(\x0e\x32$.bilibili.pangu.gallery.v1.NFTStatus\x12\x0f\n\x07item_id\x18\x08 \x01(\x03\"\xa0\x02\n\x05Order\x12\x11\n\titem_name\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07tx_time\x18\x04 \x01(\t\x12\x0e\n\x06issuer\x18\x05 \x01(\t\x12\x12\n\nissue_time\x18\x06 \x01(\t\x12\x10\n\x08token_id\x18\x07 \x01(\t\x12\x33\n\x07\x64isplay\x18\x08 \x01(\x0b\x32\".bilibili.pangu.gallery.v1.Display\x12\x18\n\x10\x63ontract_address\x18\t \x01(\t\x12\x11\n\thash_jump\x18\n \x01(\t\x12\x15\n\rcontract_jump\x18\x0b \x01(\t\x12\x1c\n\x14\x64isable_browser_jump\x18\x0c \x01(\x08\"5\n\x0eUserCheckReply\x12\x15\n\rpolicy_status\x18\x01 \x01(\x05\x12\x0c\n\x04gt14\x18\x02 \x01(\x05\"0\n\x0cUserCheckReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x13\n\x0bpolicy_type\x18\x02 \x01(\x05*2\n\nGT14Status\x12\x08\n\x04LT14\x10\x00\x12\x08\n\x04GE14\x10\x01\x12\x10\n\x0cUNKNOWN_GT14\x10\x02*1\n\tNFTStatus\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\t\n\x05\x44OING\x10\x02*<\n\x11PolicyAgreeStatus\x12\x0c\n\x08UNSIGNED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02*6\n\nPolicyType\x12\x12\n\x0eUNKNOWN_POLICY\x10\x00\x12\n\n\x06WALLET\x10\x01\x12\x08\n\x04SALE\x10\x02\x32\x9e\x06\n\x10GalleryInterface\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12\x62\n\x08UserInfo\x12).bilibili.pangu.gallery.v1.GetUserInfoReq\x1a+.bilibili.pangu.gallery.v1.GetUserInfoReply\x12h\n\x0cListNFTByMid\x12*.bilibili.pangu.gallery.v1.ListNFTByMidReq\x1a,.bilibili.pangu.gallery.v1.ListNFTByMidReply\x12n\n\x0eListOrderByMid\x12,.bilibili.pangu.gallery.v1.ListOrderByMidReq\x1a..bilibili.pangu.gallery.v1.ListOrderByMidReply\x12_\n\tBasicInfo\x12\'.bilibili.pangu.gallery.v1.BasicInfoReq\x1a).bilibili.pangu.gallery.v1.BasicInfoReply\x12_\n\tUserCheck\x12\'.bilibili.pangu.gallery.v1.UserCheckReq\x1a).bilibili.pangu.gallery.v1.UserCheckReply\x12\x65\n\x0b\x41greePolicy\x12).bilibili.pangu.gallery.v1.AgreePolicyReq\x1a+.bilibili.pangu.gallery.v1.AgreePolicyReply\x12k\n\rGetLastPolicy\x12+.bilibili.pangu.gallery.v1.GetLastPolicyReq\x1a-.bilibili.pangu.gallery.v1.GetLastPolicyReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pangu.gallery.v1.gallery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GT14STATUS']._serialized_start=1845
  _globals['_GT14STATUS']._serialized_end=1895
  _globals['_NFTSTATUS']._serialized_start=1897
  _globals['_NFTSTATUS']._serialized_end=1946
  _globals['_POLICYAGREESTATUS']._serialized_start=1948
  _globals['_POLICYAGREESTATUS']._serialized_end=2008
  _globals['_POLICYTYPE']._serialized_start=2010
  _globals['_POLICYTYPE']._serialized_end=2064
  _globals['_AGREEPOLICYREPLY']._serialized_start=99
  _globals['_AGREEPOLICYREPLY']._serialized_end=117
  _globals['_AGREEPOLICYREQ']._serialized_start=119
  _globals['_AGREEPOLICYREQ']._serialized_end=212
  _globals['_BASICINFOREPLY']._serialized_start=215
  _globals['_BASICINFOREPLY']._serialized_end=353
  _globals['_BASICINFOREQ']._serialized_start=355
  _globals['_BASICINFOREQ']._serialized_end=382
  _globals['_DISPLAY']._serialized_start=384
  _globals['_DISPLAY']._serialized_end=478
  _globals['_GETLASTPOLICYREPLY']._serialized_start=480
  _globals['_GETLASTPOLICYREPLY']._serialized_end=558
  _globals['_GETLASTPOLICYREQ']._serialized_start=560
  _globals['_GETLASTPOLICYREQ']._serialized_end=638
  _globals['_GETUSERINFOREPLY']._serialized_start=640
  _globals['_GETUSERINFOREPLY']._serialized_end=740
  _globals['_GETUSERINFOREQ']._serialized_start=742
  _globals['_GETUSERINFOREQ']._serialized_end=771
  _globals['_LINK']._serialized_start=773
  _globals['_LINK']._serialized_end=835
  _globals['_LISTNFTBYMIDREPLY']._serialized_start=837
  _globals['_LISTNFTBYMIDREPLY']._serialized_end=934
  _globals['_LISTNFTBYMIDREQ']._serialized_start=936
  _globals['_LISTNFTBYMIDREQ']._serialized_end=1040
  _globals['_LISTORDERBYMIDREPLY']._serialized_start=1042
  _globals['_LISTORDERBYMIDREPLY']._serialized_end=1145
  _globals['_LISTORDERBYMIDREQ']._serialized_start=1147
  _globals['_LISTORDERBYMIDREQ']._serialized_end=1217
  _globals['_NFT']._serialized_start=1220
  _globals['_NFT']._serialized_end=1447
  _globals['_ORDER']._serialized_start=1450
  _globals['_ORDER']._serialized_end=1738
  _globals['_USERCHECKREPLY']._serialized_start=1740
  _globals['_USERCHECKREPLY']._serialized_end=1793
  _globals['_USERCHECKREQ']._serialized_start=1795
  _globals['_USERCHECKREQ']._serialized_end=1843
  _globals['_GALLERYINTERFACE']._serialized_start=2067
  _globals['_GALLERYINTERFACE']._serialized_end=2865
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/v2/opus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/app/dynamic/v2/opus.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"\x94\x02\n\rOpusDetailReq\x12\x34\n\topus_type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.OpusType\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x10\n\x08share_id\x18\x04 \x01(\t\x12\x12\n\nshare_mode\x18\t \x01(\x05\x12\x12\n\nlocal_time\x18\n \x01(\x05\x12\x43\n\x0bplayer_args\x18\x0b \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12/\n\x06\x63onfig\x18\x0c \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Config\"F\n\x0eOpusDetailResp\x12\x34\n\topus_item\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.OpusItem\"\xc1\x01\n\x08OpusItem\x12\x0f\n\x07opus_id\x18\x01 \x01(\x03\x12\x34\n\topus_type\x18\x02 \x01(\x0e\x32!.bilibili.app.dynamic.v2.OpusType\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x30\n\x07modules\x18\x04 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.Module\x12/\n\x06\x65xtend\x18\x05 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Extend*\\\n\x08OpusType\x12\x11\n\rOPUS_TYPE_DYN\x10\x00\x12\x15\n\x11OPUS_TYPE_ARTICLE\x10\x01\x12\x12\n\x0eOPUS_TYPE_NOTE\x10\x02\x12\x12\n\x0eOPUS_TYPE_WORD\x10\x03\x32\x65\n\x04Opus\x12]\n\nOpusDetail\x12&.bilibili.app.dynamic.v2.OpusDetailReq\x1a\'.bilibili.app.dynamic.v2.OpusDetailRespb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v2.opus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OPUSTYPE']._serialized_start=699
  _globals['_OPUSTYPE']._serialized_end=791
  _globals['_OPUSDETAILREQ']._serialized_start=153
  _globals['_OPUSDETAILREQ']._serialized_end=429
  _globals['_OPUSDETAILRESP']._serialized_start=431
  _globals['_OPUSDETAILRESP']._serialized_end=501
  _globals['_OPUSITEM']._serialized_start=504
  _globals['_OPUSITEM']._serialized_end=697
  _globals['_OPUS']._serialized_start=793
  _globals['_OPUS']._serialized_end=894
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/show/region/v1/region.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/app/show/region/v1/region.proto\x12\x1b\x62ilibili.app.show.region.v1\"8\n\x0cRegionConfig\x12\x13\n\x0bscenes_name\x18\x01 \x01(\t\x12\x13\n\x0bscenes_type\x18\x02 \x01(\t\"\x85\x02\n\nRegionInfo\x12\x0b\n\x03tid\x18\x01 \x01(\x05\x12\x0c\n\x04reid\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x0c\n\x04goto\x18\x05 \x01(\t\x12\r\n\x05param\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\x05\x12\x12\n\nis_bangumi\x18\t \x01(\x05\x12\x39\n\x08\x63hildren\x18\n \x03(\x0b\x32\'.bilibili.app.show.region.v1.RegionInfo\x12\x39\n\x06\x63onfig\x18\x0b \x03(\x0b\x32).bilibili.app.show.region.v1.RegionConfig\"G\n\x0bRegionReply\x12\x38\n\x07regions\x18\x01 \x03(\x0b\x32\'.bilibili.app.show.region.v1.RegionInfo\"\x19\n\tRegionReq\x12\x0c\n\x04lang\x18\x01 \x01(\t2d\n\x06Region\x12Z\n\x06Region\x12&.bilibili.app.show.region.v1.RegionReq\x1a(.bilibili.app.show.region.v1.RegionReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.region.v1.region_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGIONCONFIG']._serialized_start=73
  _globals['_REGIONCONFIG']._serialized_end=129
  _globals['_REGIONINFO']._serialized_start=132
  _globals['_REGIONINFO']._serialized_end=393
  _globals['_REGIONREPLY']._serialized_start=395
  _globals['_REGIONREPLY']._serialized_end=466
  _globals['_REGIONREQ']._serialized_start=468
  _globals['_REGIONREQ']._serialized_end=493
  _globals['_REGION']._serialized_start=495
  _globals['_REGION']._serialized_end=595
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudPlayConfig(google.protobuf.message.Message):
    """云端保存的播放器配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_PANORAMA_FIELD_NUMBER: builtins.int
    ENABLE_DOLBY_FIELD_NUMBER: builtins.int
    ENABLE_SHAKE_FIELD_NUMBER: builtins.int
    ENABLE_BACKGROUND_FIELD_NUMBER: builtins.int
    ENABLE_LOSS_LESS_FIELD_NUMBER: builtins.int
    @property
    def enable_panorama(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用杜比全景声"""
    @property
    def enable_dolby(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用杜比音效"""
    @property
    def enable_shake(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用震动"""
    @property
    def enable_background(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用后台播放"""
    @property
    def enable_loss_less(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用HIRES"""
    def __init__(
        self,
        *,
        enable_panorama: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_dolby: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_shake: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_background: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_loss_less: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_background", b"enable_background", "enable_dolby", b"enable_dolby", "enable_loss_less", b"enable_loss_less", "enable_panorama", b"enable_panorama", "enable_shake", b"enable_shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_background", b"enable_background", "enable_dolby", b"enable_dolby", "enable_loss_less", b"enable_loss_less", "enable_panorama", b"enable_panorama", "enable_shake", b"enable_shake"]) -> None: ...

global___CloudPlayConfig = CloudPlayConfig

@typing_extensions.final
class PlayConfig(google.protobuf.message.Message):
    """播放器策略配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOULD_AUTO_PLAY_FIELD_NUMBER: builtins.int
    SHOULD_AUTO_FULLSCREEN_FIELD_NUMBER: builtins.int
    ENABLE_PLAYURL_HTTPS_FIELD_NUMBER: builtins.int
    ENABLE_DANMAKU_INTERACTION_FIELD_NUMBER: builtins.int
    SMALL_SCREEN_STATUS_FIELD_NUMBER: builtins.int
    PLAYER_CODEC_MODE_KEY_FIELD_NUMBER: builtins.int
    ENABLE_GRAVITY_ROTATE_SCREEN_FIELD_NUMBER: builtins.int
    ENABLE_DANMAKU_MONOSPACED_FIELD_NUMBER: builtins.int
    ENABLE_EDIT_SUBTITLE_FIELD_NUMBER: builtins.int
    ENABLE_SUBTITLE_FIELD_NUMBER: builtins.int
    COLOR_FILTER_FIELD_NUMBER: builtins.int
    SHOULD_AUTO_STORY_FIELD_NUMBER: builtins.int
    LANDSCAPE_AUTO_STORY_FIELD_NUMBER: builtins.int
    VOLUME_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def should_auto_play(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def should_auto_fullscreen(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_playurl_https(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_danmaku_interaction(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def small_screen_status(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def player_codec_mode_key(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def enable_gravity_rotate_screen(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_danmaku_monospaced(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_edit_subtitle(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_subtitle(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def color_filter(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def should_auto_story(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def landscape_auto_story(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def volume_balance(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        should_auto_play: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        should_auto_fullscreen: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_playurl_https: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_danmaku_interaction: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        small_screen_status: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        player_codec_mode_key: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        enable_gravity_rotate_screen: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_danmaku_monospaced: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_edit_subtitle: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_subtitle: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        color_filter: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        should_auto_story: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        landscape_auto_story: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        volume_balance: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color_filter", b"color_filter", "enable_danmaku_interaction", b"enable_danmaku_interaction", "enable_danmaku_monospaced", b"enable_danmaku_monospaced", "enable_edit_subtitle", b"enable_edit_subtitle", "enable_gravity_rotate_screen", b"enable_gravity_rotate_screen", "enable_playurl_https", b"enable_playurl_https", "enable_subtitle", b"enable_subtitle", "landscape_auto_story", b"landscape_auto_story", "player_codec_mode_key", b"player_codec_mode_key", "should_auto_fullscreen", b"should_auto_fullscreen", "should_auto_play", b"should_auto_play", "should_auto_story", b"should_auto_story", "small_screen_status", b"small_screen_status", "volume_balance", b"volume_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color_filter", b"color_filter", "enable_danmaku_interaction", b"enable_danmaku_interaction", "enable_danmaku_monospaced", b"enable_danmaku_monospaced", "enable_edit_subtitle", b"enable_edit_subtitle", "enable_gravity_rotate_screen", b"enable_gravity_rotate_screen", "enable_playurl_https", b"enable_playurl_https", "enable_subtitle", b"enable_subtitle", "landscape_auto_story", b"landscape_auto_story", "player_codec_mode_key", b"player_codec_mode_key", "should_auto_fullscreen", b"should_auto_fullscreen", "should_auto_play", b"should_auto_play", "should_auto_story", b"should_auto_story", "small_screen_status", b"small_screen_status", "volume_balance", b"volume_balance"]) -> None: ...

global___PlayConfig = PlayConfig

@typing_extensions.final
class SpecificPlayConfig(google.protobuf.message.Message):
    """灰度测试特殊功能？"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_SEGMENTED_SECTION_FIELD_NUMBER: builtins.int
    @property
    def enable_segmented_section(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        enable_segmented_section: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_segmented_section", b"enable_segmented_section"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_segmented_section", b"enable_segmented_section"]) -> None: ...

global___SpecificPlayConfig = SpecificPlayConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/network/network.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/metadata/network/network.proto\x12\x19\x62ilibili.metadata.network\"{\n\x07Network\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.metadata.network.NetworkType\x12-\n\x02tf\x18\x02 \x01(\x0e\x32!.bilibili.metadata.network.TFType\x12\x0b\n\x03oid\x18\x03 \x01(\t*^\n\x0bNetworkType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x08\n\x04WIFI\x10\x01\x12\x0c\n\x08\x43\x45LLULAR\x10\x02\x12\x0b\n\x07OFFLINE\x10\x03\x12\x0c\n\x08OTHERNET\x10\x04\x12\x0c\n\x08\x45THERNET\x10\x05*]\n\x06TFType\x12\x0e\n\nTF_UNKNOWN\x10\x00\x12\n\n\x06U_CARD\x10\x01\x12\t\n\x05U_PKG\x10\x02\x12\n\n\x06\x43_CARD\x10\x03\x12\t\n\x05\x43_PKG\x10\x04\x12\n\n\x06T_CARD\x10\x05\x12\t\n\x05T_PKG\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.network.network_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NETWORKTYPE']._serialized_start=195
  _globals['_NETWORKTYPE']._serialized_end=289
  _globals['_TFTYPE']._serialized_start=291
  _globals['_TFTYPE']._serialized_end=384
  _globals['_NETWORK']._serialized_start=70
  _globals['_NETWORK']._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/im/type/im.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x62ilibili/im/type/im.proto\x12\x10\x62ilibili.im.type\",\n\x0b\x41\x63\x63ountInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pic_url\x18\x02 \x01(\t\"Q\n\x0e\x46riendRelation\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x11\n\tvip_level\x18\x04 \x01(\r\"\xeb\x01\n\rGroupRelation\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x11\n\towner_uid\x18\x02 \x01(\x04\x12\x12\n\ngroup_type\x18\x03 \x01(\r\x12\x13\n\x0bgroup_level\x18\x04 \x01(\r\x12\x13\n\x0bgroup_cover\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x14\n\x0cgroup_notice\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\x05\x12\x13\n\x0bmember_role\x18\t \x01(\x05\x12\x17\n\x0f\x66\x61ns_medal_name\x18\n \x01(\t\x12\x0f\n\x07room_id\x18\x0b \x01(\x04\"5\n\x08HighText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\"H\n\x07ImgInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x11\n\timageType\x18\x04 \x01(\t\"\\\n\x0bKeyHitInfos\x12\r\n\x05toast\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\r\x12-\n\thigh_text\x18\x03 \x03(\x0b\x32\x1a.bilibili.im.type.HighText\"\xaf\x02\n\x05Medal\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x10\n\x08medal_id\x18\x02 \x01(\x05\x12\r\n\x05level\x18\x03 \x01(\x05\x12\x12\n\nmedal_name\x18\x04 \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x05\x12\x10\n\x08intimacy\x18\x06 \x01(\x05\x12\x15\n\rmaster_status\x18\x07 \x01(\x05\x12\x12\n\nis_receive\x18\x08 \x01(\x05\x12\x19\n\x11medal_color_start\x18\t \x01(\x03\x12\x17\n\x0fmedal_color_end\x18\n \x01(\x03\x12\x1a\n\x12medal_color_border\x18\x0b \x01(\x03\x12\x18\n\x10medal_color_name\x18\x0c \x01(\x03\x12\x19\n\x11medal_color_level\x18\r \x01(\x03\x12\x13\n\x0bguard_level\x18\x0e \x01(\x03\"\xcf\x03\n\x03Msg\x12\x12\n\nsender_uid\x18\x01 \x01(\x04\x12\x33\n\rreceiver_type\x18\x02 \x01(\x0e\x32\x1c.bilibili.im.type.RecverType\x12\x13\n\x0breceiver_id\x18\x03 \x01(\x04\x12\x12\n\ncli_msg_id\x18\x04 \x01(\x04\x12+\n\x08msg_type\x18\x05 \x01(\x0e\x32\x19.bilibili.im.type.MsgType\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x11\n\tmsg_seqno\x18\x07 \x01(\x04\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12\x0f\n\x07\x61t_uids\x18\t \x03(\x04\x12\x12\n\nrecver_ids\x18\n \x03(\x04\x12\x0f\n\x07msg_key\x18\x0b \x01(\x04\x12\x12\n\nmsg_status\x18\x0c \x01(\r\x12\x12\n\nsys_cancel\x18\r \x01(\x08\x12\x13\n\x0bnotify_code\x18\x0e \x01(\t\x12/\n\nmsg_source\x18\x0f \x01(\x0e\x32\x1b.bilibili.im.type.MsgSource\x12\x18\n\x10new_face_version\x18\x10 \x01(\x05\x12\x34\n\rkey_hit_infos\x18\x11 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"\xcb\x01\n\x0bRelationLog\x12\x33\n\x08log_type\x18\x01 \x01(\x0e\x32!.bilibili.im.type.RelationLogType\x12\x13\n\x0boplog_seqno\x18\x02 \x01(\x04\x12\x39\n\x0f\x66riend_relation\x18\x03 \x01(\x0b\x32 .bilibili.im.type.FriendRelation\x12\x37\n\x0egroup_relation\x18\x04 \x01(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xf9\x04\n\x0bSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x10\n\x08\x61t_seqno\x18\x03 \x01(\x04\x12\x0e\n\x06top_ts\x18\x04 \x01(\x04\x12\x12\n\ngroup_name\x18\x05 \x01(\t\x12\x13\n\x0bgroup_cover\x18\x06 \x01(\t\x12\x11\n\tis_follow\x18\x07 \x01(\r\x12\x0e\n\x06is_dnd\x18\x08 \x01(\r\x12\x11\n\tack_seqno\x18\t \x01(\x04\x12\x0e\n\x06\x61\x63k_ts\x18\n \x01(\x04\x12\x12\n\nsession_ts\x18\x0b \x01(\x04\x12\x14\n\x0cunread_count\x18\x0c \x01(\r\x12\'\n\x08last_msg\x18\r \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x12\n\ngroup_type\x18\x0e \x01(\r\x12\x10\n\x08\x63\x61n_fold\x18\x0f \x01(\r\x12\x0e\n\x06status\x18\x10 \x01(\r\x12\x11\n\tmax_seqno\x18\x11 \x01(\x04\x12\x14\n\x0cnew_push_msg\x18\x12 \x01(\r\x12\x0f\n\x07setting\x18\x13 \x01(\r\x12\x13\n\x0bis_guardian\x18\x14 \x01(\r\x12\x14\n\x0cis_intercept\x18\x15 \x01(\x05\x12\x10\n\x08is_trust\x18\x16 \x01(\x05\x12\x17\n\x0fsystem_msg_type\x18\x17 \x01(\x05\x12\x33\n\x0c\x61\x63\x63ount_info\x18\x18 \x01(\x0b\x32\x1d.bilibili.im.type.AccountInfo\x12\x13\n\x0blive_status\x18\x19 \x01(\x05\x12\x1c\n\x14\x62iz_msg_unread_count\x18\x1a \x01(\x05\x12/\n\nuser_label\x18\x1b \x01(\x0b\x32\x1b.bilibili.im.type.UserLabel\"b\n\tUserLabel\x12\x12\n\nlabel_type\x18\x01 \x01(\x05\x12&\n\x05medal\x18\x02 \x01(\x0b\x32\x17.bilibili.im.type.Medal\x12\x19\n\x11guardian_relation\x18\x03 \x01(\x05*\x94\x06\n\x05\x43mdId\x12\x15\n\x11\x45N_CMD_ID_INVALID\x10\x00\x12\x18\n\x12\x45N_CMD_ID_SEND_MSG\x10\xc1\x9a\x0c\x12\x18\n\x12\x45N_CMD_ID_SYNC_MSG\x10\xa1\xc2\x1e\x12\x1d\n\x17\x45N_CMD_ID_SYNC_RELATION\x10\xa2\xc2\x1e\x12\x18\n\x12\x45N_CMD_ID_SYNC_ACK\x10\xa3\xc2\x1e\x12\'\n!EN_CMD_ID_SYNC_FETCH_SESSION_MSGS\x10\xa6\xc2\x1e\x12(\n\"EN_CMD_ID_SESSION_SVR_GET_SESSIONS\x10\xc1\x84=\x12(\n\"EN_CMD_ID_SESSION_SVR_NEW_SESSIONS\x10\xc2\x84=\x12(\n\"EN_CMD_ID_SESSION_SVR_ACK_SESSIONS\x10\xc3\x84=\x12&\n EN_CMD_ID_SESSION_SVR_UPDATE_ACK\x10\xc4\x84=\x12#\n\x1d\x45N_CMD_ID_SESSION_SVR_SET_TOP\x10\xc5\x84=\x12*\n$EN_CMD_ID_SESSION_SVR_REMOVE_SESSION\x10\xc7\x84=\x12)\n#EN_CMD_ID_SESSION_SVR_SINGLE_UNREAD\x10\xc8\x84=\x12+\n%EN_CMD_ID_SESSION_SVR_MY_GROUP_UNREAD\x10\xc9\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_UPDATE_UNFLW_READ\x10\xca\x84=\x12+\n%EN_CMD_ID_SESSION_SVR_GROUP_ASSIS_MSG\x10\xcb\x84=\x12)\n#EN_CMD_ID_SESSION_SVR_ACK_ASSIS_MSG\x10\xcc\x84=\x12*\n$EN_CMD_ID_SESSION_SVR_SESSION_DETAIL\x10\xcf\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_BATCH_SESS_DETAIL\x10\xd0\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_BATCH_RM_SESSIONS\x10\xd1\x84=*I\n\x11\x45NUM_BIZ_MSG_TYPE\x12\x17\n\x13\x42IZ_MSG_TYPE_NORMAL\x10\x00\x12\x1b\n\x17\x42IZ_MSG_TYPE_CARD_VIDEO\x10\x01*\x94\x03\n\tMsgSource\x12\x18\n\x14\x45N_MSG_SOURCE_UNKONW\x10\x00\x12\x15\n\x11\x45N_MSG_SOURCE_IOS\x10\x01\x12\x19\n\x15\x45N_MSG_SOURCE_ANDRIOD\x10\x02\x12\x14\n\x10\x45N_MSG_SOURCE_H5\x10\x03\x12\x14\n\x10\x45N_MSG_SOURCE_PC\x10\x04\x12\x1b\n\x17\x45N_MSG_SOURCE_BACKSTAGE\x10\x05\x12\x15\n\x11\x45N_MSG_SOURCE_BIZ\x10\x06\x12\x15\n\x11\x45N_MSG_SOURCE_WEB\x10\x07\x12\'\n#EN_MSG_SOURCE_AUTOREPLY_BY_FOLLOWED\x10\x08\x12*\n&EN_MSG_SOURCE_AUTOREPLY_BY_RECEIVE_MSG\x10\t\x12\'\n#EN_MSG_SOURCE_AUTOREPLY_BY_KEYWORDS\x10\n\x12%\n!EN_MSG_SOURCE_AUTOREPLY_BY_VOYAGE\x10\x0b\x12\x1f\n\x1b\x45N_MSG_SOURCE_VC_ATTACH_MSG\x10\x0c*\x8c\x0f\n\x07MsgType\x12\x17\n\x13\x45N_INVALID_MSG_TYPE\x10\x00\x12\x14\n\x10\x45N_MSG_TYPE_TEXT\x10\x01\x12\x13\n\x0f\x45N_MSG_TYPE_PIC\x10\x02\x12\x15\n\x11\x45N_MSG_TYPE_AUDIO\x10\x03\x12\x15\n\x11\x45N_MSG_TYPE_SHARE\x10\x04\x12\x19\n\x15\x45N_MSG_TYPE_DRAW_BACK\x10\x05\x12\x1b\n\x17\x45N_MSG_TYPE_CUSTOM_FACE\x10\x06\x12\x18\n\x14\x45N_MSG_TYPE_SHARE_V2\x10\x07\x12\x1a\n\x16\x45N_MSG_TYPE_SYS_CANCEL\x10\x08\x12\x1c\n\x18\x45N_MSG_TYPE_MINI_PROGRAM\x10\t\x12\x1a\n\x16\x45N_MSG_TYPE_NOTIFY_MSG\x10\n\x12\x1a\n\x16\x45N_MSG_TYPE_VIDEO_CARD\x10\x0b\x12\x1c\n\x18\x45N_MSG_TYPE_ARTICLE_CARD\x10\x0c\x12\x1c\n\x18\x45N_MSG_TYPE_PICTURE_CARD\x10\r\x12!\n\x1d\x45N_MSG_TYPE_COMMON_SHARE_CARD\x10\x0e\x12\x1c\n\x18\x45N_MSG_TYPE_BIZ_MSG_TYPE\x10\x32\x12\x1f\n\x1b\x45N_MSG_TYPE_MODIFY_MSG_TYPE\x10\x33\x12$\n EN_MSG_TYPE_GROUP_MEMBER_CHANGED\x10\x65\x12$\n EN_MSG_TYPE_GROUP_STATUS_CHANGED\x10\x66\x12%\n!EN_MSG_TYPE_GROUP_DYNAMIC_CHANGED\x10g\x12\"\n\x1e\x45N_MSG_TYPE_GROUP_LIST_CHANGED\x10h\x12#\n\x1f\x45M_MSG_TYPE_FRIEND_LIST_CHANGED\x10i\x12$\n EN_MSG_TYPE_GROUP_DETAIL_CHANGED\x10j\x12)\n%EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED\x10k\x12!\n\x1d\x45N_MSG_TYPE_NOTICE_WATCH_LIST\x10l\x12)\n%EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED\x10m\x12&\n\"EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED\x10n\x12*\n&EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED\x10o\x12&\n\"EN_MSG_TYPE_NOTIFY_NEW_UP_RECIEVED\x10p\x12,\n(EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED_V2\x10q\x12)\n%EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED_V2\x10r\x12-\n)EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED_V2\x10s\x12*\n&EN_MSG_TYPE_GROUP_DETAIL_CHANGED_MULTI\x10t\x12/\n+EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED_MULTI\x10u\x12#\n\x1f\x45N_MSG_TYPE_NOTIFY_ANTI_DISTURB\x10v\x12$\n\x1f\x45N_MSG_TYPE_SYS_GROUP_DISSOLVED\x10\xc9\x01\x12!\n\x1c\x45N_MSG_TYPE_SYS_GROUP_JOINED\x10\xca\x01\x12(\n#EN_MSG_TYPE_SYS_GROUP_MEMBER_EXITED\x10\xcb\x01\x12&\n!EN_MSG_TYPE_SYS_GROUP_ADMIN_FIRED\x10\xcc\x01\x12(\n#EN_MSG_TYPE_SYS_GROUP_MEMBER_KICKED\x10\xcd\x01\x12)\n$EN_MSG_TYPE_SYS_GROUP_ADMIN_KICK_OFF\x10\xce\x01\x12%\n EN_MSG_TYPE_SYS_GROUP_ADMIN_DUTY\x10\xcf\x01\x12\'\n\"EN_MSG_TYPE_SYS_GROUP_AUTO_CREATED\x10\xd0\x01\x12!\n\x1c\x45N_MSG_TYPE_SYS_FRIEND_APPLY\x10\xd2\x01\x12%\n EN_MSG_TYPE_SYS_FRIEND_APPLY_ACK\x10\xd3\x01\x12,\n\'EN_MSG_TYPE_SYS_GROUP_APPLY_FOR_JOINING\x10\xd4\x01\x12\x34\n/EN_MSG_TYPE_SYS_GROUP_ADMIN_ACCEPTED_USER_APPLY\x10\xd5\x01\x12#\n\x1e\x45N_MSG_TYPE_CHAT_MEMBER_JOINED\x10\xad\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_MEMBER_EXITED\x10\xae\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_GROUP_FREEZED\x10\xaf\x02\x12%\n EN_MSG_TYPE_CHAT_GROUP_DISSOLVED\x10\xb0\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_GROUP_CREATED\x10\xb1\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_POPUP_SESSION\x10\xb2\x02*l\n\nRecverType\x12\x11\n\rEN_NO_MEANING\x10\x00\x12\x17\n\x13\x45N_RECVER_TYPE_PEER\x10\x01\x12\x18\n\x14\x45N_RECVER_TYPE_GROUP\x10\x02\x12\x18\n\x14\x45N_RECVER_TYPE_PEERS\x10\x03*y\n\x0fRelationLogType\x12\x17\n\x13\x45N_INVALID_LOG_TYPE\x10\x00\x12\x11\n\rEN_ADD_FRIEND\x10\x01\x12\x14\n\x10\x45N_REMOVE_FRIEND\x10\x02\x12\x11\n\rEN_JOIN_GROUP\x10\x03\x12\x11\n\rEN_EXIT_GROUP\x10\x04*\x82\x01\n\x0cSESSION_TYPE\x12\x18\n\x14INVALID_SESSION_TYPE\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.im.type.im_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CMDID']._serialized_start=2352
  _globals['_CMDID']._serialized_end=3140
  _globals['_ENUM_BIZ_MSG_TYPE']._serialized_start=3142
  _globals['_ENUM_BIZ_MSG_TYPE']._serialized_end=3215
  _globals['_MSGSOURCE']._serialized_start=3218
  _globals['_MSGSOURCE']._serialized_end=3622
  _globals['_MSGTYPE']._serialized_start=3625
  _globals['_MSGTYPE']._serialized_end=5557
  _globals['_RECVERTYPE']._serialized_start=5559
  _globals['_RECVERTYPE']._serialized_end=5667
  _globals['_RELATIONLOGTYPE']._serialized_start=5669
  _globals['_RELATIONLOGTYPE']._serialized_end=5790
  _globals['_SESSION_TYPE']._serialized_start=5793
  _globals['_SESSION_TYPE']._serialized_end=5923
  _globals['_ACCOUNTINFO']._serialized_start=47
  _globals['_ACCOUNTINFO']._serialized_end=91
  _globals['_FRIENDRELATION']._serialized_start=93
  _globals['_FRIENDRELATION']._serialized_end=174
  _globals['_GROUPRELATION']._serialized_start=177
  _globals['_GROUPRELATION']._serialized_end=412
  _globals['_HIGHTEXT']._serialized_start=414
  _globals['_HIGHTEXT']._serialized_end=467
  _globals['_IMGINFO']._serialized_start=469
  _globals['_IMGINFO']._serialized_end=541
  _globals['_KEYHITINFOS']._serialized_start=543
  _globals['_KEYHITINFOS']._serialized_end=635
  _globals['_MEDAL']._serialized_start=638
  _globals['_MEDAL']._serialized_end=941
  _globals['_MSG']._serialized_start=944
  _globals['_MSG']._serialized_end=1407
  _globals['_RELATIONLOG']._serialized_start=1410
  _globals['_RELATIONLOG']._serialized_end=1613
  _globals['_SESSIONINFO']._serialized_start=1616
  _globals['_SESSIONINFO']._serialized_end=2249
  _globals['_USERLABEL']._serialized_start=2251
  _globals['_USERLABEL']._serialized_end=2349
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.dynamic.v1 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2


class DynamicStub(object):
    """v1动态
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DynVideo = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynVideo',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReqReply.FromString,
                )
        self.DynDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReply.FromString,
                )
        self.SVideo = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/SVideo',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReply.FromString,
                )
        self.DynTab = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynTab',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReply.FromString,
                )
        self.DynOurCitySwitch = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynOurCitySwitch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCitySwitchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynOurCity = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynOurCity',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReply.FromString,
                )
        self.DynVideoPersonal = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynVideoPersonal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
                )
        self.DynUpdOffset = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynUpdOffset',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynUpdOffsetReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynRed = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynRed',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReply.FromString,
                )
        self.DynMixUpListViewMore = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynMixUpListViewMore',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
                )
        self.DynMixUpListSearch = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/DynMixUpListSearch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReply.FromString,
                )
        self.OurCityClickReport = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/OurCityClickReport',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReply.FromString,
                )
        self.GeoCoder = channel.unary_unary(
                '/bilibili.app.dynamic.v1.Dynamic/GeoCoder',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReply.FromString,
                )


class DynamicServicer(object):
    """v1动态
    """

    def DynVideo(self, request, context):
        """动态视频页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynDetails(self, request, context):
        """批量动态id获取动态详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SVideo(self, request, context):
        """小视频连播页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynTab(self, request, context):
        """动态tab页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynOurCitySwitch(self, request, context):
        """同城接口开关
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynOurCity(self, request, context):
        """动态同城页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVideoPersonal(self, request, context):
        """最近访问-个人视频feed流
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynUpdOffset(self, request, context):
        """最近访问-标记已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynRed(self, request, context):
        """动态红点接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynMixUpListViewMore(self, request, context):
        """查看更多-列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynMixUpListSearch(self, request, context):
        """查看更多-搜索
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OurCityClickReport(self, request, context):
        """同城点击上报
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeoCoder(self, request, context):
        """位置定位
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DynamicServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DynVideo': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideo,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReqReply.SerializeToString,
            ),
            'DynDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReply.SerializeToString,
            ),
            'SVideo': grpc.unary_unary_rpc_method_handler(
                    servicer.SVideo,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReply.SerializeToString,
            ),
            'DynTab': grpc.unary_unary_rpc_method_handler(
                    servicer.DynTab,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReply.SerializeToString,
            ),
            'DynOurCitySwitch': grpc.unary_unary_rpc_method_handler(
                    servicer.DynOurCitySwitch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCitySwitchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynOurCity': grpc.unary_unary_rpc_method_handler(
                    servicer.DynOurCity,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReply.SerializeToString,
            ),
            'DynVideoPersonal': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideoPersonal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReply.SerializeToString,
            ),
            'DynUpdOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.DynUpdOffset,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynUpdOffsetReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynRed': grpc.unary_unary_rpc_method_handler(
                    servicer.DynRed,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReply.SerializeToString,
            ),
            'DynMixUpListViewMore': grpc.unary_unary_rpc_method_handler(
                    servicer.DynMixUpListViewMore,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListViewMoreReply.SerializeToString,
            ),
            'DynMixUpListSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.DynMixUpListSearch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReply.SerializeToString,
            ),
            'OurCityClickReport': grpc.unary_unary_rpc_method_handler(
                    servicer.OurCityClickReport,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReply.SerializeToString,
            ),
            'GeoCoder': grpc.unary_unary_rpc_method_handler(
                    servicer.GeoCoder,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.dynamic.v1.Dynamic', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Dynamic(object):
    """v1动态
    """

    @staticmethod
    def DynVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynVideo',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoReqReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynDetails',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/SVideo',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.SVideoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynTab',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynOurCitySwitch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynOurCitySwitch',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCitySwitchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynOurCity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynOurCity',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynOurCityReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVideoPersonal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynVideoPersonal',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynUpdOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynUpdOffset',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynUpdOffsetReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynRed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynRed',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynRedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynMixUpListViewMore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynMixUpListViewMore',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.NoReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynMixUpListSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/DynMixUpListSearch',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.DynMixUpListSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OurCityClickReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/OurCityClickReport',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.OurCityClickReportReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeoCoder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v1.Dynamic/GeoCoder',
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v1_dot_dynamic__pb2.GeoCoderReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/device/device.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/metadata/device/device.proto\x12\x18\x62ilibili.metadata.device\"\xfc\x01\n\x06\x44\x65vice\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x10\n\x08platform\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x07 \x01(\t\x12\r\n\x05\x62rand\x18\x08 \x01(\t\x12\r\n\x05model\x18\t \x01(\t\x12\r\n\x05osver\x18\n \x01(\t\x12\x10\n\x08\x66p_local\x18\x0b \x01(\t\x12\x11\n\tfp_remote\x18\x0c \x01(\t\x12\x14\n\x0cversion_name\x18\r \x01(\t\x12\n\n\x02\x66p\x18\x0e \x01(\t\x12\x0b\n\x03\x66ts\x18\x0f \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.device.device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DEVICE']._serialized_start=68
  _globals['_DEVICE']._serialized_end=320
# @@protoc_insertion_point(module_scope)
